@@ -88,6 +88,9 @@ elif board_id == ap_board.CORAL_EDGE_TPU_DEV:
 elif board_id == ap_board.ODROID_C2:
     from adafruit_blinka.board.odroidc2 import *
 
+elif board_id == ap_board.ODROID_N2:
+   from adafruit_blinka.board.odroidn2 import *
+
 elif board_id == ap_board.DRAGONBOARD_410C:
     from adafruit_blinka.board.dragonboard_410c import *
 
